Crate snarkvm_synthesizer_process

Crate snarkvm_synthesizer_process 

Structs

Authorization
CallMetrics
FinalizeRegisters
FinalizeTypes
InclusionAssignment
InclusionV0Assignment
Process
RegisterTypes
Registers
Stack
Trace

Enums

CallStack
The CallStack is used to track the current state of the program execution.
ConsensusFeeVersion
InclusionAssignmentWrapper
InclusionVersion

Traits

CallTrait

Functions

constructor_cost_in_microcredits_v1
Returns the minimum number of microcredits required to run the constructor in the given stack. If a constructor does not exist, no cost is incurred.
constructor_cost_in_microcredits_v2
Returns the minimum number of microcredits required to run the constructor in the given stack. If a constructor does not exist, no cost is incurred.
cost_in_microcredits_v1
Returns the minimum number of microcredits required to run the finalize (deprecated).
cost_in_microcredits_v2
Returns the minimum number of microcredits required to run the finalize.
cost_in_microcredits_v3
Returns the minimum number of microcredits required to run the finalize using the ARC-0005 cost reduction factor.
cost_per_command
Returns the the cost of a command in a finalize scope.
deploy_compute_cost_in_microcredits
Returns the compute cost for a deployment in microcredits. This is used to limit the amount of single-threaded compute in the block generation hot path. This does NOT represent the full costs which a user has to pay.
deployment_cost
Returns the deployment cost in microcredits for a given deployment.
deployment_cost_v1
Returns the minimum cost in microcredits to publish the given deployment.
deployment_cost_v2
Returns the minimum cost in microcredits to publish the given deployment using the ARC_0005_COMPUTE_DISCOUNT.
execute_compute_cost_in_microcredits
Returns the compute cost for an execution in microcredits. This is used to limit the amount of single-threaded compute in the block generation hot path. This does NOT represent the full costs which a user has to pay.
execution_cost
Returns the execution cost in microcredits for a given execution.
execution_cost_for_authorization
Returns the execution cost in microcredits for a given `Authorization.

Type Aliases

Assignments
ConstructorCost
DeployCostDetails
ExecuteCostDetails
FinalizeCost
MinimumCost
NamespaceCost
StorageCost
SynthesisCost