pub struct RegisterTypes<N: Network> { /* private fields */ }Implementations
Sourceimpl<N: Network> RegisterTypes<N>
impl<N: Network> RegisterTypes<N>
Sourcepub fn matches_struct(
&self,
stack: &Stack<N>,
operands: &[Operand<N>],
struct_: &StructType<N>,
) -> Result<()>
pub fn matches_struct( &self, stack: &Stack<N>, operands: &[Operand<N>], struct_: &StructType<N>, ) -> Result<()>
Checks that the given operands matches the layout of the struct. The ordering of the operands matters.
Sourcepub fn matches_array(
&self,
stack: &Stack<N>,
operands: &[Operand<N>],
array_type: &ArrayType<N>,
) -> Result<()>
pub fn matches_array( &self, stack: &Stack<N>, operands: &[Operand<N>], array_type: &ArrayType<N>, ) -> Result<()>
Checks that the given operands matches the layout of the array.
Sourcepub fn matches_record(
&self,
stack: &Stack<N>,
operands: &[Operand<N>],
record_type: &RecordType<N>,
) -> Result<()>
pub fn matches_record( &self, stack: &Stack<N>, operands: &[Operand<N>], record_type: &RecordType<N>, ) -> Result<()>
Checks that the given record matches the layout of the record type.
Sourceimpl<N: Network> RegisterTypes<N>
impl<N: Network> RegisterTypes<N>
Sourcepub fn from_closure(stack: &Stack<N>, closure: &Closure<N>) -> Result<Self>
pub fn from_closure(stack: &Stack<N>, closure: &Closure<N>) -> Result<Self>
Initializes a new instance of RegisterTypes for the given closure.
Checks that the given closure is well-formed for the given stack.
Sourcepub fn from_function(stack: &Stack<N>, function: &Function<N>) -> Result<Self>
pub fn from_function(stack: &Stack<N>, function: &Function<N>) -> Result<Self>
Initializes a new instance of RegisterTypes for the given function.
Checks that the given function is well-formed for the given stack.
Sourcepub fn contains(&self, register: &Register<N>) -> bool
pub fn contains(&self, register: &Register<N>) -> bool
Returns true if the given register exists.
Sourcepub fn is_input(&self, register: &Register<N>) -> bool
pub fn is_input(&self, register: &Register<N>) -> bool
Returns true if the given register corresponds to an input register.
Sourcepub fn get_type_from_operand(
&self,
stack: &impl StackTrait<N>,
operand: &Operand<N>,
) -> Result<RegisterType<N>>
pub fn get_type_from_operand( &self, stack: &impl StackTrait<N>, operand: &Operand<N>, ) -> Result<RegisterType<N>>
Returns the register type of the given operand.
Sourcepub fn get_type(
&self,
stack: &impl StackTrait<N>,
register: &Register<N>,
) -> Result<RegisterType<N>>
pub fn get_type( &self, stack: &impl StackTrait<N>, register: &Register<N>, ) -> Result<RegisterType<N>>
Returns the register type of the given register.