Stack

Struct Stack 

pub struct Stack<N: Network> { /* private fields */ }

Implementations

Source

impl<N: Network> Stack<N>

pub fn authorize<A: Aleo<Network = N>, R: Rng + CryptoRng>( &self, private_key: &PrivateKey<N>, function_name: impl TryInto<Identifier<N>>, inputs: impl ExactSizeIterator<Item = impl TryInto<Value<N>>>, rng: &mut R, ) -> Result<Authorization<N>, StackAuthError>

Authorizes a call to the program function for the given inputs.

pub fn authorize_unchecked<A: Aleo<Network = N>, R: Rng + CryptoRng>( &self, private_key: &PrivateKey<N>, function_name: impl TryInto<Identifier<N>>, inputs: impl ExactSizeIterator<Item = impl TryInto<Value<N>>>, rng: &mut R, ) -> Result<Authorization<N>, StackAuthError>

Authorizes a call to the program function for the given inputs. Compared to authorize, this method does not check for circuit satisfiability of the request.

pub fn sample_authorization<A: Aleo<Network = N>, R: Rng + CryptoRng>( &self, address: Address<A::Network>, program_id: ProgramID<A::Network>, function_name: Identifier<A::Network>, inputs: impl ExactSizeIterator<Item = impl TryInto<Value<A::Network>>>, rng: &mut R, ) -> Result<Authorization<N>, StackAuthError>

Produces a mocked Authorization for a call to the given function on the supplied inputs using the provided caller address. The resulting Authorization has the same size as the one which would be produced (and signed) using the private key corresponding to that address and can therefore be used to compute the cost of the associated Execution, but many of its values (such as the input IDs in the Requests) may not be correct. This method does not check circuit satisfiability or Request validity.

pub fn authorize_request<A: Aleo<Network = N>, R: Rng + CryptoRng>( &self, request: Request<N>, rng: &mut R, ) -> Result<Authorization<N>, StackAuthError>

Authorizes a call to a public function for the given request. Compared to authorize, no private key is needed, but this only works for single public requests.

Source

impl<N: Network> Stack<N>

pub fn deploy<A: Aleo<Network = N>, R: Rng + CryptoRng>( &self, rng: &mut R, ) -> Result<Deployment<N>>

Deploys the given program ID, if it does not exist.

pub fn verify_deployment<A: Aleo<Network = N>, R: Rng + CryptoRng>( &self, _consensus_version: ConsensusVersion, deployment: &Deployment<N>, rng: &mut R, ) -> Result<()>

Checks each function in the program on the given verifying key and certificate.

Source

impl<N: Network> Stack<N>

pub fn evaluate_closure<A: Aleo<Network = N>>( &self, closure: &Closure<N>, inputs: &[Value<N>], call_stack: CallStack<N>, signer: Address<N>, caller: Address<N>, tvk: Field<N>, ) -> Result<Vec<Value<N>>, StackEvalError>

Evaluates a program closure on the given inputs.

Errors

This method will halt if the given inputs are not the same length as the input statements.

pub fn evaluate_function<A: Aleo<Network = N>, R: CryptoRng + Rng>( &self, call_stack: CallStack<N>, caller: Option<ProgramID<N>>, root_tvk: Option<Field<N>>, rng: &mut R, ) -> Result<Response<N>, StackEvalError>

Evaluates a program function on the given inputs.

Errors

This method will halt if the given inputs are not the same length as the input statements.

Source

impl<N: Network> Stack<N>

pub fn execute_closure<A: Aleo<Network = N>>( &self, closure: &Closure<N>, inputs: &[Value<A>], call_stack: CallStack<N>, signer: Address<A>, caller: Address<A>, tvk: Field<A>, ) -> Result<Vec<Value<A>>, StackExecError>

Executes a program closure on the given inputs.

Errors

This method will halt if the given inputs are not the same length as the input statements.

pub fn execute_function<A: Aleo<Network = N>, R: CryptoRng + Rng>( &self, call_stack: CallStack<N>, console_caller: Option<ProgramID<N>>, console_root_tvk: Option<Field<N>>, rng: &mut R, ) -> Result<Response<N>, StackExecError>

Executes a program function on the given inputs.

Note: To execute a transition, do not call this method. Instead, call Process::execute.

Errors

This method will halt if the given inputs are not the same length as the input statements.

Source

impl<N: Network> Stack<N>

pub fn check_upgrade_is_valid( old_program: &Program<N>, new_program: &Program<N>, ) -> Result<()>

Checks that the new program is a valid upgrade. At a high-level, an upgrade must preserve the existing interfaces of the original program. An upgrade may add new components, except for constructors, and modify logic only in functions and finalize scopes. An upgrade may also be exactly the same as the original program.

The order of the components in the new program may be modified, as long as the interfaces remain the same.

An detailed overview of what an upgrade can and cannot do is given below:

Program ComponentDeleteModifyAdd
import
constructor
mapping
struct
record
closure
function✅ (logic)
finalize✅ (logic)
view✅ (logic)
—————–––––––––––––—––

There is one important caveat in that output register indices MUST remain the same. For example, changing output r10 as <NAME>.record into output r11 as <NAME>.record would not be a valid upgrade. This restriction is necessary because the output register index is instantiated as a constant in the caller circuit. This check is enforced in check_transaction in synthesizer/src/vm/verify.rs.

Source

impl<N: Network> Stack<N>

pub fn sample_plaintext<R: Rng + CryptoRng>( &self, plaintext_type: &PlaintextType<N>, rng: &mut R, ) -> Result<Plaintext<N>>

Samples a plaintext value according to the given plaintext type.

pub fn sample_future<R: Rng + CryptoRng>( &self, locator: &Locator<N>, rng: &mut R, ) -> Result<Future<N>>

Samples a future value according to the given future type.

pub fn sample_dynamic_future<R: Rng + CryptoRng>( &self, rng: &mut R, ) -> Result<DynamicFuture<N>>

Samples a dynamic future value.

pub fn sample_dynamic_record<R: Rng + CryptoRng>( &self, rng: &mut R, ) -> Result<DynamicRecord<N>>

Samples a dynamic record value.

Source

impl<N: Network> Stack<N>

pub fn synthesize_key<A: Aleo<Network = N>, R: Rng + CryptoRng>( &self, function_name: &Identifier<N>, rng: &mut R, ) -> Result<()>

Synthesizes the proving key and verifying key for the given function name.

pub fn synthesize_from_assignment( &self, function_name: &Identifier<N>, assignment: &Assignment<N::Field>, ) -> Result<()>

Synthesizes and stores the (proving_key, verifying_key) for the given function name and assignment.

pub fn synthesize_translation_key<A: Aleo<Network = N>, R: Rng + CryptoRng>( &self, record_name: &Identifier<N>, rng: &mut R, ) -> Result<()>

Synthesizes the proving key and verifying key for the translation circuit of the record with the given name.

Source

impl<N: Network> Stack<N>

pub fn new(process: &Process<N>, program: &Program<N>) -> Result<Self>

Initializes a new stack given the process and the program.

pub fn new_raw( process: &Process<N>, program: &Program<N>, edition: u16, ) -> Result<Self>

Partially initializes a new stack, given the process and the program, without checking for validity. Unlike Stack::new, this method accepts an explicit edition and skips upgrade validation, which is necessary for amendments that preserve the existing edition rather than incrementing it. A Stack created by this method must also call initialize_and_check.

pub fn initialize_and_check(&self, process: &Process<N>) -> Result<()>

Initializes and checks the register state and well-formedness of the stack, even if it has already been initialized.

pub fn get_constructor_types(&self) -> Result<FinalizeTypes<N>>

Returns the constructor types for the program.

pub fn get_register_types( &self, name: &Identifier<N>, ) -> Result<RegisterTypes<N>>

Returns the register types for the given closure or function name.

pub fn get_finalize_types( &self, name: &Identifier<N>, ) -> Result<FinalizeTypes<N>>

Returns the register types for the given finalize name.

pub fn get_view_types(&self, name: &Identifier<N>) -> Result<FinalizeTypes<N>>

Returns the register types for the given view function name.