pub struct TranslationAssignment<N: Network> { /* private fields */ }Expand description
Data collected during execution and used to prove record translation in dynamic calls.
Implementations
Sourceimpl<N: Network> TranslationAssignment<N>
impl<N: Network> TranslationAssignment<N>
Sourcepub fn new(
record_static: Record<N, Plaintext<N>>,
record_dynamic: DynamicRecord<N>,
program_id: ProgramID<N>,
function_id: Field<N>,
record_name: Identifier<N>,
is_to_static: bool,
is_external_record: bool,
tvk: Field<N>,
record_view_key: Option<Field<N>>,
gamma: Option<Group<N>>,
record_register_index: u16,
id_dynamic: Field<N>,
id_static: Field<N>,
) -> Self
pub fn new( record_static: Record<N, Plaintext<N>>, record_dynamic: DynamicRecord<N>, program_id: ProgramID<N>, function_id: Field<N>, record_name: Identifier<N>, is_to_static: bool, is_external_record: bool, tvk: Field<N>, record_view_key: Option<Field<N>>, gamma: Option<Group<N>>, record_register_index: u16, id_dynamic: Field<N>, id_static: Field<N>, ) -> Self
Initializes a new translation assignment.
Sourcepub fn to_circuit_assignment<A: Aleo<Network = N>>(
&self,
translation_index: u16,
) -> Result<Assignment<N::Field>>
pub fn to_circuit_assignment<A: Aleo<Network = N>>( &self, translation_index: u16, ) -> Result<Assignment<N::Field>>
The circuit for record-translation verification
Operation outline
The [[ ]] notation is used to denote public inputs or constants.
ⓘ
cm = commit([[program_id]], [[record_name]], record_static, record_view_key)
sn = serial_number(cm, gamma)
actual_id_non_external = is_to_static ? sn : cm
actual_id_external = HashPSD8([[function_id]] | record_static | tvk | [[record_register_index]])
actual_id_static = is_external ? actual_id_external : actual_id_non_external
actual_id_dynamic = HashPSD8([[function_id]] | record_dynamic | tvk | [[record_register_index]])
assert record_static.owner == record_dynamic.owner
assert record_static.nonce == record_dynamic.nonce
assert record_static.version == record_dynamic.version
assert merkleize(record_static) == record_dynamic.root
assert [[id_record_static]] == actual_id_static
assert [[id_record_dynamic]] == actual_id_dynamicTrait Implementations