Structs
- Authorization
- Call
Metrics - Finalize
Registers - Finalize
Types - Inclusion
Assignment - Inclusion
V0Assignment - Process
- Register
Types - Registers
- Stack
- Trace
Enums
- Call
Stack - The
CallStackis used to track the current state of the program execution. - Consensus
FeeVersion - Inclusion
Assignment Wrapper - Inclusion
Version
Traits
Functions
- constructor_
cost_ in_ microcredits_ v1 - Returns the minimum number of microcredits required to run the constructor in the given stack. If a constructor does not exist, no cost is incurred.
- constructor_
cost_ in_ microcredits_ v2 - Returns the minimum number of microcredits required to run the constructor in the given stack. If a constructor does not exist, no cost is incurred.
- cost_
in_ microcredits_ v1 - Returns the minimum number of microcredits required to run the finalize (deprecated).
- cost_
in_ microcredits_ v2 - Returns the minimum number of microcredits required to run the finalize.
- cost_
in_ microcredits_ v3 - Returns the minimum number of microcredits required to run the finalize using the ARC-0005 cost reduction factor.
- cost_
per_ command - Returns the the cost of a command in a finalize scope.
- deploy_
compute_ cost_ in_ microcredits - Returns the compute cost for a deployment in microcredits. This is used to limit the amount of single-threaded compute in the block generation hot path. This does NOT represent the full costs which a user has to pay.
- deployment_
cost - Returns the deployment cost in microcredits for a given deployment.
- deployment_
cost_ v1 - Returns the minimum cost in microcredits to publish the given deployment.
- deployment_
cost_ v2 - Returns the minimum cost in microcredits to publish the given deployment using the ARC_0005_COMPUTE_DISCOUNT.
- execute_
compute_ cost_ in_ microcredits - Returns the compute cost for an execution in microcredits. This is used to limit the amount of single-threaded compute in the block generation hot path. This does NOT represent the full costs which a user has to pay.
- execution_
cost - Returns the execution cost in microcredits for a given execution.
- execution_
cost_ for_ authorization - Returns the execution cost in microcredits for a given `Authorization.